# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import shutil
import tempfile
import unittest

from lava_test.core.parsers import TestParser
from tests.fixtures import TestCaseWithFixtures
from lava_test.core.artifacts import TestArtifacts
from tests.imposters import OutputImposter, ConfigImposter

class testTestParser(TestCaseWithFixtures):
    def setUp(self):
        self.config = self.add_fixture(ConfigImposter())
        self.out = self.add_fixture(OutputImposter())
        self.origdir = os.path.abspath(os.curdir)
        self.filename = os.path.abspath(__file__)
        self.test_id = "ABC"
        self.artifacts = TestArtifacts.allocate(self.test_id, self.config)
        os.chdir(self.artifacts.results_dir)

    def tearDown(self):
        os.chdir(self.origdir)
        shutil.rmtree(self.artifacts.results_dir)

    def makeparser(self, *args, **kwargs):
        return TestParser(*args, **kwargs)

    def writeoutputlog(self, str):
        with open("testoutput.log", "a") as fd:
            fd.write(str)

    def test_parse(self):
        pattern = "^(?P<testid>\w+):\W+(?P<result>\w+)"
        self.writeoutputlog("test001: pass")
        parser = self.makeparser(pattern)
        parser.parse(self.artifacts)
        self.assertTrue(parser.results["test_results"][0]["testid"] == "test001" and
                        parser.results["test_results"][0]["result"] == "pass")

    def test_fixupdict(self):
        pattern = "^(?P<testid>\w+):\W+(?P<result>\w+)"
        fixup = {"pass":"PASS"}
        self.writeoutputlog("test001: pass")
        parser = self.makeparser(pattern, fixupdict=fixup)
        parser.parse(self.artifacts)
        self.assertEquals("PASS", parser.results["test_results"][0]["result"])

    def test_appendall(self):
        pattern = "^(?P<testid>\w+):\W+(?P<result>\w+)"
        append = {"units":"foo/s"}
        self.writeoutputlog("test001: pass")
        parser = self.makeparser(pattern, appendall=append)
        parser.parse(self.artifacts)
        self.assertEqual("foo/s", parser.results["test_results"][0]["units"])

